@@ -3,7 +3,8 @@ from typing import Generator
 import inflection
 
 from .refs import ResolverFunc
-from .schema_class import SchemaClass, get_schema_classes
+from .schema_class import get_schema_classes
+from .schema_class_model import SchemaClass
 from .schema_module import _get_schema_module, SchemaModule
 from ..module_path import ModulePath
 from ...openapi import model as openapi
